function integratorMsfcn(block)
% Example Level-2 M file S-Function.
%
% This S-function implements a continuous time integrator.
%
% For more details about S-functions, see simulink\blocks\msfuntmpl.m
%
% Author: Phil Goddard (phil@goddardconsulting.ca)
% Date:   Q1, 2008
 
setup(block);
  
%endfunction

function setup(block)
  
  % Register number of dialog parameters   
  block.NumDialogPrms = 1;

  % Register number of input and output ports
  block.NumInputPorts  = 1;
  block.NumOutputPorts = 1;

  % Setup functional port properties to dynamically be inherited.
  block.SetPreCompInpPortInfoToDynamic;
  block.SetPreCompOutPortInfoToDynamic;
 
  block.InputPort(1).Dimensions        = 1;
  block.InputPort(1).DirectFeedthrough = false;
  
  block.OutputPort(1).Dimensions       = 1;
  
  % Set block sample time to continuous
  block.SampleTimes = [0 0];
  
  % Setup Dwork
  block.NumContStates = 1;

  % Set the block simStateCompliance to default (i.e., same as a built-in block)
  block.SimStateCompliance = 'DefaultSimState';

  % Register block methods
  block.RegBlockMethod('InitializeConditions',    @InitConditions);  
  block.RegBlockMethod('Outputs',                 @Output);  
  block.RegBlockMethod('Derivatives',             @Derivative);  
  
%endfunction

function InitConditions(block)

  % Initialize Dwork
  block.ContStates.Data = block.DialogPrm(1).Data;
  
%endfunction

function Output(block)
% y = xdot

  block.OutputPort(1).Data = block.ContStates.Data;
  
%endfunction

function Derivative(block)
% xdot = u
	block.Derivatives.Data = block.InputPort(1).Data;
  
%endfunction

